@@ -23,13 +23,6 @@ from ost import conop, seq, io, mol, geom
 
 class ModellingTests(unittest.TestCase):
 
-    def setUp(self):
-        compound_lib = conop.CompoundLib.Load(
-            'data/compounds.chemlib')
-        conop.SetDefaultLib(compound_lib)
-        io.profiles['DEFAULT'].processor = conop.RuleBasedProcessor(
-            compound_lib)
-
     #######################################################################
     # HELPERs
     #######################################################################
